<?php

/**
 * @file
 * Administrative page callbacks for the amocrm_api module.
 */

/**
 * General configuration form for controlling the amocrm_api behaviour.
 */
function amocrm_api_admin_settings() {
  $form['amocrm_api_default_domain'] = array(
    '#type' => 'textfield',
    '#title' => t('Default domain'),
    '#default_value' => variable_get('amocrm_api_default_domain'),
  );

  $form['amocrm_api_default_email'] = array(
    '#type' => 'textfield',
    '#title' => t('Default email'),
    '#default_value' => variable_get('amocrm_api_default_email'),
  );

  $form['amocrm_api_default_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Default api key'),
    '#default_value' => variable_get('amocrm_api_default_key'),
  );

  try {
    $amo_client = amocrm_api_get_default_client();
    if (!empty($amo_client)) {
      $account_info = amocrm_api_account_load($amo_client);
      $form['amocrm_api_custom_fields'] = array(
        '#type' => 'fieldset',
        '#title' => t('Custom fields'),
        '#tree' => TRUE,
        '#collapsible' => TRUE,
        '#collapsed' => FALSE,
      );
      foreach ($account_info['custom_fields'] as $key => $field) {
        if (!empty($field)) {
          $form['amocrm_api_custom_fields'][$key] = array(
            '#type' => 'fieldset',
            '#title' => t('Custom field: "' . ucfirst($key) . '"'),
            '#tree' => TRUE,
            '#collapsible' => TRUE,
            '#collapsed' => TRUE,
          );
          foreach ($field as $item) {
            $code = $item['code'];
            $form['amocrm_api_custom_fields'][$key][$code] = array(
              '#type' => 'textfield',
              '#title' => $item['name'] . ' [' . $code . ']',
              '#default_value' => $item['id'],
              '#disabled' => TRUE,
            );
          }
        }
      }
    }
  }
  catch (Exception $e) {
    watchdog_exception('amoCRM API', $e);
  }

  return system_settings_form($form);
}
